@@ -104,8 +104,8 @@ class EntityUpdateOpts(TypedDict):
 class EntityListOpts(TypedDict):
     to_date: Optional[str]
     from_date: Optional[str]
-    page: Optional[str | int]
-    page_limit: Optional[str | int]
+    page: Optional[int]
+    page_limit: Optional[int]
     page_cursor: Optional[str]
     status: Optional[str]
     type: Optional[str]
